0.2.35 (2024-06-30)
-------------------

A lot of small improvements and bugfixes in this release.

- Add defer to loading the javascript for the podlove web player
- #56 removed old documentation
- #136 Only use blog cover image as a fallback for episode cover images, not the iTunes artwork
- #140 Workaround for the page_ptr ValueError in preview serving (ignore it)
- #150 Make cover image alt text work by passing it through repositories
- #152 Add a canonical link to the blog / podcast index page
- #153 JavaScript dependency updates and new bundle
- #154 Output all relative file paths + file contents to be able to pass it to the llm command
- #155 Update theme endpoint breaks on integer json payloads
- #156 Image IDs for galleries have to be integer
- #157 Fix some chooser blocks breaking on integer values for get_prep_value
